==> wilmar-in-domain-0.0.86-sources.jar: com/xforceplus/wilmar/entity/Salesbill.java <==
package com.xforceplus.wilmar.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-06-22
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class Salesbill implements Serializable {

  private static final long serialVersionUID=1L;

  private String salesbillNo;

  private String sellerNo;

  private String sellerName;

  private String sellerTaxNo;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private String externalId;

  private String purchaserNo;

  private String purchaserName;

  private String purchaserTaxNo;

  private String systemOrig;

  private String salesbillType;

  private Long priceMethod;

  private BigDecimal amountWithTax;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal alreadyMakeAmountWithTax;

  private BigDecimal alreadyMakeAmountWithoutTax;

  private BigDecimal alreadyMakeAmountTaxAmount;

  private String cooperateFlag;

  private String configurationStatus;

  private BigDecimal matchProgress;

  private String makeoutStatus;

  private String customerNo;

  private String remark;

  private String auditStatus;

  private String auditRemark;

  private String authStatus;

  private String handlingMethod;

  private String configurationMethod;

  private String sellerTel;

  private String sellerAddress;

  private String sellerBankName;

  private String sellerBankAccount;

  private String purchaserTel;

  private String purchaserAddress;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private BigDecimal discountWithTaxTotal;

  private BigDecimal discountWithoutTaxTotal;

  private BigDecimal discountTaxAmountTotal;

  private BigDecimal outterDiscountWithTax;

  private BigDecimal outterDiscountWithoutTax;

  private BigDecimal innerDiscountWithTax;

  private BigDecimal innerDiscountWithoutTax;

  private BigDecimal outterPrepayAmountWithTax;

  private BigDecimal outterPrepayAmountWithoutTax;

  private BigDecimal innerPrepayAmountWithTax;

  private BigDecimal innerPrepayAmountWithoutTax;

  private String originInvoiceNo;

  private String originInvoiceCode;

  private String redNotification;

  private String checkerName;

  private String cashierName;

  private String invoicerName;

  private String receiveUserEmail;

  private String receiveUserTel;

  private String sysOrgCode;

  private String addressee;

  private String addresseeTel;

  private String addresseeProvince;

  private String addresseeCity;

  private String addresseeCounty;

  private String direction;

  private String logisticRemark;

  private String invoiceType;

  private Long sellerId;

  private Long purchaserId;

  private BigDecimal proportionMatched;

  private String businessBillType;

  private String multHandlingMethod;

  private String receiveConfirmFlag;

  private String uploadConfirmFlag;

  private String tenantCode;

  private String errorMsg;

  private String confirmationStatus;

  private BigDecimal preMatchAmount;

  private String errorType;

  private Long farmerCooperative;

  private Long noCertification;

  private String bookkeepingStatus;

  private String cause;

  private String postingDate;

  private String postingMsg;

  private String auditSystemOrig;

  private String status;

  private String sellerCompanyNo;

  private String attachs;




        }

==> wilmar-in-domain-0.0.122-sources.jar: com/xforceplus/wilmar/entity/Salesbill.java <==
package com.xforceplus.wilmar.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-12
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class Salesbill implements Serializable {

  private static final long serialVersionUID=1L;

  private String salesbillNo;

  private String sellerNo;

  private String sellerName;

  private String sellerTaxNo;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private String externalId;

  private String purchaserNo;

  private String purchaserName;

  private String purchaserTaxNo;

  private String systemOrig;

  private String salesbillType;

  private Long priceMethod;

  private BigDecimal amountWithTax;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal alreadyMakeAmountWithTax;

  private BigDecimal alreadyMakeAmountWithoutTax;

  private BigDecimal alreadyMakeAmountTaxAmount;

  private String cooperateFlag;

  private String configurationStatus;

  private BigDecimal matchProgress;

  private String makeoutStatus;

  private String customerNo;

  private String remark;

  private String auditStatus;

  private String auditRemark;

  private String authStatus;

  private String handlingMethod;

  private String configurationMethod;

  private String sellerTel;

  private String sellerAddress;

  private String sellerBankName;

  private String sellerBankAccount;

  private String purchaserTel;

  private String purchaserAddress;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private BigDecimal discountWithTaxTotal;

  private BigDecimal discountWithoutTaxTotal;

  private BigDecimal discountTaxAmountTotal;

  private BigDecimal outterDiscountWithTax;

  private BigDecimal outterDiscountWithoutTax;

  private BigDecimal innerDiscountWithTax;

  private BigDecimal innerDiscountWithoutTax;

  private BigDecimal outterPrepayAmountWithTax;

  private BigDecimal outterPrepayAmountWithoutTax;

  private BigDecimal innerPrepayAmountWithTax;

  private BigDecimal innerPrepayAmountWithoutTax;

  private String originInvoiceNo;

  private String originInvoiceCode;

  private String redNotification;

  private String checkerName;

  private String cashierName;

  private String invoicerName;

  private String receiveUserEmail;

  private String receiveUserTel;

  private String sysOrgCode;

  private String addressee;

  private String addresseeTel;

  private String addresseeProvince;

  private String addresseeCity;

  private String addresseeCounty;

  private String direction;

  private String logisticRemark;

  private String invoiceType;

  private Long sellerId;

  private Long purchaserId;

  private BigDecimal proportionMatched;

  private String businessBillType;

  private String multHandlingMethod;

  private String receiveConfirmFlag;

  private String uploadConfirmFlag;

  private String tenantCode;

  private String errorMsg;

  private String confirmationStatus;

  private BigDecimal preMatchAmount;

  private String errorType;

  private Long farmerCooperative;

  private Long noCertification;

  private String bookkeepingStatus;

  private String cause;

  private String postingDate;

  private String postingMsg;

  private String auditSystemOrig;

  private String status;

  private String sellerCompanyNo;

  private String attachs;

  private String matchNo;

  private LocalDateTime matchTime;

  private String workflowId;

  private String auditDate;

  private String purchaseOrder;

  private String purchaseNo;

  private String invoiceAmount;

  private String businessId;




        }
